Skip to contents

Progress Widget

Usage

progress(id, value = 0, options = NULL, wrap = TRUE)

Arguments

id

a character string to specify the unique id for the widget

value

the progress value to display (should be between 0 and 100)

options

an optional list of parameters to tune the widget

wrap

whether or not the widget should be wrapped into a div container

Value

an HTML widget

Examples

if (FALSE) { # \dontrun{
progress()
} # }