Gauge Widget
gauge.RdAn animated SVG gauge widget
Details
id is used to compute ids for children nodes of the svg widget, pretty much
like the namespace id in Shiny modules.
To ensure uniqueness when used in Shiny modules, the id of the module instance
should be used as a prefix id = paste(id, "gauge", sep = "-).
The div container used when wrap = TRUE comes with basic style (width: 300px,
height: 300px, margin: 20px) to avoid the widget to occupy the whole page.
If you wish to specify other values or options, set wrap = FALSE and encapsulate
the widget in your own div.