progress.Rd
Progress Widget
progress(id, value = 0, options = NULL, wrap = TRUE)
a character string to specify the unique id for the widget
the progress value to display (should be between 0 and 100)
an optional list of parameters to tune the widget
whether or not the widget should be wrapped into a div container
an HTML widget
if (FALSE) { # \dontrun{ progress() } # }